==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/html/HTMLUListElement.cpp <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#include "config.h"
#include "HTMLUListElement.h"

#include "CSSPropertyNames.h"
#include "CSSValueKeywords.h"
#include "HTMLNames.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_OR_ISO_ALLOCATED_IMPL(HTMLUListElement);

using namespace HTMLNames;

HTMLUListElement::HTMLUListElement(const QualifiedName& tagName, Document& document)
    : HTMLElement(tagName, document)
{
    ASSERT(hasTagName(ulTag));
}

Ref<HTMLUListElement> HTMLUListElement::create(Document& document)
{
    return adoptRef(*new HTMLUListElement(ulTag, document));
}

Ref<HTMLUListElement> HTMLUListElement::create(const QualifiedName& tagName, Document& document)
{
    return adoptRef(*new HTMLUListElement(tagName, document));
}

bool HTMLUListElement::hasPresentationalHintsForAttribute(const QualifiedName& name) const
{
    if (name == typeAttr)
        return true;
    return HTMLElement::hasPresentationalHintsForAttribute(name);
}

void HTMLUListElement::collectPresentationalHintsForAttribute(const QualifiedName& name, const AtomString& value, MutableStyleProperties& style)
{
    if (name == typeAttr) {
        auto valueLowerCase = value.convertToASCIILowercase();
        if (valueLowerCase == "disc"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueDisc);
        else if (valueLowerCase == "circle"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueCircle);
        else if (valueLowerCase == "round"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueRound);
        else if (valueLowerCase == "square"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueSquare);
        else if (valueLowerCase == "none"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueNone);
    } else
        HTMLElement::collectPresentationalHintsForAttribute(name, value, style);
}

}

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebCore/html/HTMLUListElement.cpp <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#include "config.h"
#include "HTMLUListElement.h"

#include "CSSPropertyNames.h"
#include "CSSValueKeywords.h"
#include "HTMLNames.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(HTMLUListElement);

using namespace HTMLNames;

HTMLUListElement::HTMLUListElement(const QualifiedName& tagName, Document& document)
    : HTMLElement(tagName, document)
{
    ASSERT(hasTagName(ulTag));
}

Ref<HTMLUListElement> HTMLUListElement::create(Document& document)
{
    return adoptRef(*new HTMLUListElement(ulTag, document));
}

Ref<HTMLUListElement> HTMLUListElement::create(const QualifiedName& tagName, Document& document)
{
    return adoptRef(*new HTMLUListElement(tagName, document));
}

bool HTMLUListElement::hasPresentationalHintsForAttribute(const QualifiedName& name) const
{
    if (name == typeAttr)
        return true;
    return HTMLElement::hasPresentationalHintsForAttribute(name);
}

void HTMLUListElement::collectPresentationalHintsForAttribute(const QualifiedName& name, const AtomString& value, MutableStyleProperties& style)
{
    if (name == typeAttr) {
        auto valueLowerCase = value.convertToASCIILowercase();
        if (valueLowerCase == "disc"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueDisc);
        else if (valueLowerCase == "circle"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueCircle);
        else if (valueLowerCase == "round"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueRound);
        else if (valueLowerCase == "square"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueSquare);
        else if (valueLowerCase == "none"_s)
            addPropertyToPresentationalHintStyle(style, CSSPropertyListStyleType, CSSValueNone);
    } else
        HTMLElement::collectPresentationalHintsForAttribute(name, value, style);
}

}
